#
# spec file for package python-getmac
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-getmac
Version:        0.9.4
Release:        1.2
Summary:        Module to get MAC addresses of remote hosts and local interfaces
License:        MIT
URL:            https://github.com/GhostofGoes/getmac
Source:         https://files.pythonhosted.org/packages/source/g/getmac/getmac-%{version}.tar.gz
# PATCH-FIX-OPENSUSE
Patch0:         cope-with-no-ip6.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A Python module to get MAC addresses of remote hosts and local interfaces.

%prep
%autosetup -p1 -n getmac-%{version}
sed -i "1,4{/\/usr\/bin\/env/d}" getmac/__main__.py
rm -r *egg-info
find . -type f -exec chmod -x {} \;

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/getmac
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=C.UTF-8
# test_cli_main fails in OBS not local run
# test_cli_multiple_debug_levels  same as above
%pytest tests -k 'not test_cli_main and not test_cli_multiple_debug_levels'

%post
%python_install_alternative getmac

%postun
%python_uninstall_alternative getmac

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%python_alternative %{_bindir}/getmac
%{python_sitelib}/getmac
%{python_sitelib}/getmac-%{version}.dist-info

%changelog
* Fri Mar  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.9.4:
  * Support BusyBox's ``arping``
  * Improve how ARP is handled. If ``ArpFile`` method succeeds, use it
    instead of ``ArpingHost``
  * Speed up the first call to ``ArpingHost``
  * Fix FORCE_METHOD not being respected for IPv4 macs
  * Fix `ArpFile` method being used for IPv6
  * Deprecate Python 3.6 support
  * This release is a *complete rewrite of getmac from the ground up*. The
    public API of `getmac` is **unchanged** as part of this rewrite.
  * Fully support Python 3.9
  * Tentatively support Python 3.10 and 3.11
  * `arping` (POSIX) or `SendARP` (Windows) will now *always* be used instead
    of sending a UDP packet when looking for the MAC of a IPv4 host, if
    they're available and operable (otherwise, UDP + ARP table check will be
    used like before).
  * Added ability to override the detected platform via `--override-platform`
    argument (CLI) or `getmac.getmac.OVERRIDE_PLATFORM` variable (Python).
    This will force methods for that platform to be used, regardless of the
    actual platform.
  * Overhauled `ifconfig` parsing. It should now be far more reliable and
    accurate across all platforms.
  * Fixed bug with `/proc/net/route` parsing
  * Removed man pages from distribution (`getmac.1`/`getmac2.1`). They were
    severely out of date and unused.
- Drop patches fix-failing-darwin-test.patch and support-python3.9.patch
- Add patch cope-with-no-ip6.patch
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- 0.8.3 (12/10/2021)
  Announcement: Compatibility with Python versions older than 3.6 (2.7, 3.4, and 3.5) is deprecated and will be removed in getmac 1.0.0.
  If you are stuck on an unsupported Python, considor loosely pinning the version of this package in your dependency list, e.g. getmac<1.
  Changed
  Added support for Thomas Habets' version of arping in addition to the existing iputils one (contributed by Ville Skyttä (@scop) in #52 and #54)
  Added support for docker in network bridge mode (contributed by Tomasz Duda (@tomaszduda23) in #57)
  Add CHANGELOG URL to PyPI metadata (contributed by Ville Skyttä (@scop) in #58)
  Fixed code quality test suite errors (includes changes by Daniel Flanagan (@FlantasticDan) in #67)
  Improved Android support (contributed by @emadmahdi in #71)
  Minor code quality fixes (2 years of neglecting master branch)
  Add Code of Conduct for project contributors
  Add SECURITY.md for reporting security issues (e.g. vulnerabilities)
  Deprecate Python 3.4 and 3.5
  Issue deprecation message as a warning in addition to a log message
* Fri Apr 16 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patch to fix build by skipping a test that doesn't work as
  expected:
  * fix-failing-darwin-test.patch
- Add patch to fix build with python 3.9:
  * support-python3.9.patch
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip test_cli_main as it fails for some reason on OBS
* Thu Apr 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix all files having executable bit
* Mon Apr  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.8.2
  * Added warning about Python 2 compatibility being dropped in 1.0.0
  * Officially support Python 3.8
  * Documented a known issue with looking up IP of a local interface on Linux/WSL (See the "Known Issues" section in the README)
  * Added remote host lookup using `arping` as last resort
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase/full sentences for summary/description.
* Wed Sep  4 2019 Antonio Larrosa <alarrosa@suse.com>
- Initial release of python-getmac 0.8.1
